# ai-models-aurora

ai-models-aurora is an [ai-models](https://github.com/ecmwf-lab/ai-models) plugin to run Microsoft's [Aurora](https://github.com/microsoft/aurora).

[Aurora, arXiv:2405.13063](https://arxiv.org/abs/2405.13063)

Aurora was created by Cristian Bodnar, Wessel P. Bruinsma, Ana Lucic, Megan Stanley, Johannes Brandstetter, Patrick Garvan, Maik Riechert, Jonathan Weyn, Haiyu Dong, Anna Vaughan, Jayesh K. Gupta, Kit Tambiratnam, Alex Archibald, Elizabeth Heider, Max Welling, Richard E. Turner, Paris Perdikaris.

See https://microsoft.github.io/aurora/intro.html for more information.

The model weights are made available for use under the terms of the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International (CC BY-NC-SA 4.0). You may obtain a copy of the License at: https://creativecommons.org/licenses/by-nc-sa/4.0/.

## Installation

To install the package, run:

```bash
pip install ai-models-aurora
```

This will install the package and its dependencies.
